<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation>Rayon invalide</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation>Aucune solution</translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Sélectionnez l&apos;entité ou de la région</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Déplacer entité ou référence</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Définir deuxième point d&apos;angle</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Spécifiez le point cible de point de référence</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Spécifiez le point cible de la sélection</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Déplacer entité</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Déplacer référence</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Déplacer sélection</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Déplacer entité</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>Édition bloc &apos;%1&apos;&lt;br&gt;Choisissez &lt;i&gt;Bloc &gt; Retour au dessin principal&lt;/i&gt; lorsque vous avez terminé</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>Outil actif:</translation>
    </message>
    <message>
        <source>Active Tool: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Outil actif: %1</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Options de bloc</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Principaux outils</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>Outils de CAO</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entité est sur un calque verrouillé.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>Longueur :</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entité n&apos;est pas une référence de bloc.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entité n&apos;est pas une ligne ou un arc.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>Entité n&apos;est pas une ligne, un arc ou une polyligne.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entité n&apos;est pas une ligne.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entité n&apos;est pas un arc ou un cercle.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entité n&apos;est pas une ligne, un arc ou un cercle.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entité n&apos;est pas un arc, un cercle ou une ellipse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>Entité n&apos;est pas une ligne, un arc, un cercle ou une ellipse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>Entité n&apos;est pas une ligne, un arc, un cercle, une ellipse ou polyligne.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>Entité n&apos;est pas une ligne, un arc, un cercle, une ellipse ou une spline.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>Entité n&apos;est pas une ligne, un arc, un cercle, une ellipse, une spline ou polyligne.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entité n&apos;est pas une polyligne.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Rayon chuté en dessous de zéro après %1 cercle(s) concentrique(s).</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Rayon chuté en dessous de zéro, après %1 arc(s) concentrique(s).</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Au moins deux points sont identiques.</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Aucun cercle possible.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Aucun arc possible.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Invalid nombre de segments :.%1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Invalid ellipse majeurs / mineurs : %1 /.%2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>Restaurer les valeurs par défaut</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>Insérer symbole</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>Diamètre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Arc</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Degré</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>Plus / minus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Presque égale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Asymptotiquement égal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>Racine carrée</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>Phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>Alt phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Multiplication</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Division</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>Carré</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Texte empilé</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Valeur mesurée</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Alignée</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Milieu</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Ajustement</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>En haut</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Base</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>En bas</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation>Sens horaire</translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation>Sens antihoraire</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation>Au-dessus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <source>Loading plugins...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Chargement plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins...</source>
        <translation type="obsolete">Initialisation des plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Initialisation des plugins :</translation>
    </message>
    <message>
        <source>Post-initializing plugins...</source>
        <translation type="obsolete">Initialisation des plugins...</translation>
    </message>
    <message>
        <source>Post-Initialization...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Post-initialisation ...</translation>
    </message>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Chargement add-on traductions...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Chargement add-ons...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Initialisation des add-ons...</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Post-initialisation...</translation>
    </message>
    <message>
        <source>Loading add-on translations ...</source>
        <translation type="obsolete">Chargement add-on traductions ...</translation>
    </message>
    <message>
        <source>Loading add-ons ...</source>
        <translation type="obsolete">Chargement add-ons ...</translation>
    </message>
    <message>
        <source>Initializing add-ons ...</source>
        <translation type="obsolete">Initialisation des add-ons ...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Initialisation des add-ons :</translation>
    </message>
    <message>
        <source>Post-initializing add-ons ...</source>
        <translation type="obsolete">Post-initialisation ...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>Objets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>Objet</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>Objets inconnues</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>Objet inconnue</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>Blocs</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>Bloc</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>Calques</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>Calque</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation>Présentations</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation>Présentation</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>Types de ligne</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>Type de ligne</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>Vues</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Entité</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Entités</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>3dFaces</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>3dFace</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Références de bloc</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translatorcomment>--google--
Choisissez la référence de bloc
Modifier un bloc basé sur une référence de bloc choisie</translatorcomment>
        <translation>Référence de bloc</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Références de bloc et attributs</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Référence de bloc et attributs</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc</source>
        <translation>Arc</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arcs</source>
        <translatorcomment>--google--
Dessine des arcs
Dessine des arcs avec 3 points
Dessine des parallèles aux cercles, arcs et lignes existants</translatorcomment>
        <translation>Arcs</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Attributs</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Attribut</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Aéfinitions d&apos;attributs</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Définition de l&apos;attribut</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circle</source>
        <translation>Cercle</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circles</source>
        <translatorcomment>--google--
Dessine des parallèles aux cercles, arcs et lignes existants
Dessine des cercles avec un centre et un point
Dessine des cercles avec 2 points</translatorcomment>
        <translation>Cercles</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Cotations</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Cotation</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimension</source>
        <translation>Cotation alignée</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotations alignées</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimension</source>
        <translation>Cotation angulaire</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimensions</source>
        <translation>Cotations angulaires</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation>2 lignes cotations angulaires</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation>2 lignes cotation angulaire</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation>3 points cotations angulaires</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation>3 points cotation angulaire</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation>Cotation de l&apos;arc</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimension</source>
        <translation>Cotation diamétrale</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotations diamétrales</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimension</source>
        <translation>Cotation ordonnée</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotations ordonnées</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotations tournés</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotation tourné</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimension</source>
        <translation>Cotation radiale</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotations radiales</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipses</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ellipses</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatch</source>
        <translation>Hachure</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatches</source>
        <translatorcomment>--google--
Dessine des hachures et des remplissages unis
&amp;Combiner hachures
Combiner hachures</translatorcomment>
        <translation>Hachures</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Images</source>
        <translatorcomment>--google--
&lt;img src=&quot;:/trolltech/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Recherche à partir du début
&lt;img src=&quot;:/trolltech/assistant/images/wrap.png&quot;&gt;nbsp;Recherche à partir du début
&lt;img src=&quot;:/trolltech/shared/images/wrap.png&quot;&gt;&amp;nbsp;Recherche à partir du début</translatorcomment>
        <translation>Images</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leader</source>
        <translation>Repère</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leaders</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Repères</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Lines</source>
        <translatorcomment>--google--
Dessine des parallèles aux cercles, arcs et lignes existants
Dessine des lignes
Impossible de fermer la séquence de lignes : nombre d&apos;entités définies encore insuffisant.</translatorcomment>
        <translation>Lignes</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Lignes infinies</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Ligne infinie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Rayons</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Rayon</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>Points</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>Point</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>Polylignes</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>Polyligne</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solid</source>
        <translation>Trait continu</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solids</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Traits continus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Traces</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation>Faces</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation>Face</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>Spline</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Texte basé</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Textes</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Fenêtres</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entités inconnues</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entité inconnue</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Première entité ne peut pas être ajuster.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Entité ne peut pas être ajuster.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Deuxième entité ne peut pas être ajuster.</translation>
    </message>
</context>
</TS>
